Method: RestClient#get_request
- Defined in:
- lib/clearconnect/rest_client.rb
#get_request(query) ⇒ Object
Takes a query of the format { key: ‘value’, key2: ‘value’ } where the keys are symbols corresponding to the parameters passed to the ClearConnect REST API
16 17 18 19 20 21 22 23 24 25 26 |
# File 'lib/clearconnect/rest_client.rb', line 16 def get_request(query) if @session and @sessionKey.nil? raise "Invalid session key. You must first acquire a session key by calling 'get_session_key' before executing requests." elsif not @session query = normalize_query(query.merge(:sessionKey => @sessionKey)) = { :query => query } self.class.get("", ) else get_no_session(query) end end |